@@ -15,7 +15,7 @@ import time
 class CPEnv(Env):
     print("正在搭建初始环境2")
     print("文件位置：", sys.argv[0])
-    dic_clfs1 = np.load('dic_clfs.npy', allow_pickle=True).item()
+    dic_clfs1 = np.load('/content/drive/MyDrive/Colab Notebooks/dic_clfs.npy', allow_pickle=True).item()
     print(dic_clfs1['xl2'].shape, dic_clfs1['yl2'].shape, dic_clfs1['xl3'].shape, dic_clfs1['yl3'].shape)
 
     metadata = {'render.modes': ['human']}
@@ -26,12 +26,13 @@ class CPEnv(Env):
 
         self.X_train = np.load('dic_clfs.npy', allow_pickle=True).item()['xl2']
         self.y_train = np.load('dic_clfs.npy', allow_pickle=True).item()['yl2']
+        # print(self.X_train.shape)
         # self.X_val = np.load('dic_clfs.npy', allow_pickle=True).item()['xl3']
         # self.y_val = np.load('dic_clfs.npy', allow_pickle=True).item()['yl3']
 
-        self.observation_space = (1, self.X_train.shape[1])
+        self.observation_space = spaces.Box(0,1, shape=(self.X_train.shape[1],),dtype=np.float64)
         # self.observation_space = spaces.Box(low=0, high=1, shape=(1, self.X_train.shape[1]), dtype=np.float32)
-        print("self.observation_space=", self.observation_space)
+        # print("self.observation_space=", self.observation_space)
         self.action_space = spaces.Discrete(2)
         # self.action_space = spaces.MultiDiscrete([2] * self.hangshu)
 
@@ -69,6 +70,14 @@ class CPEnv(Env):
         self.true_value = self.y_train[self.jishu]
         self.jishu = self.jishu + 1
 
+
+        if self.true_value == 1:
+            # print(self.true_value)
+            self.right_nums = 1
+        else:
+            # print(self.true_value)
+            self.right_nums = 0
+
         return self.state
 
     def step(self, action):
@@ -82,25 +91,43 @@ class CPEnv(Env):
         self.done = False
 
         if self.true_value == 1:
-            print(self.true_value)
-            self.right_nums = self.right_nums + 1
+            # print(self.true_value)
+            self.right_nums = 1
+            if action == 1:
+                reward = 1
+                self.score = 1
+            else:
+                reward = 0
+                self.score = 0
+        else:
+            # print(self.true_value)
+            self.right_nums = 0
+
+            if action == 1:
+                reward = -1
+                self.score = 0
+            else:
+                reward = 0
+                self.score = 0
+            reward = 0
 
         # reward
         # Calculate the reward
-        if action == 1:
-            if self.true_value == 1:
-                reward = 1
-                self.score = self.score + 1
-            else:
-                reward = -1
+        # if action == 1:
+        #     if self.true_value == 1:
+        #         reward = 1
+        #         self.score = 1
+        #     else:
+        #         reward = -1
+        #         self.score = 0
 
         # elif prediction == 0:
         #     if prediction == self.true_value:
         #         reward = 0.5
         #     else:
         #         reward = 0
-        else:
-            reward = 0
+        # else:
+        #     reward = 0
 
         # next state
         self.state = self.X_train[self.jishu]
@@ -112,6 +139,7 @@ class CPEnv(Env):
         info['right_nums'] = self.right_nums
 
         # print("one step is over")
+        # print(type(self.state))
         return self.state, reward, self.done, info
 
     def render(self, mode='human'):
